Alesis M1Active monitor MK2 coppia di monitor bi amplificati a € 430,00 solo da MusicHouseBari.it
Description: Alesis M1Active monitor MK2 coppia di monitor bi amplificati Alesis M1Active monitor MK2 coppia di monitor ATTIVI bi-amplificati 80W rms <br /> <br /> <br /> By combining our expertise in reference monitor design with our proven track record in studio amplification, Alesis'' new M1 Active Biamplified Reference

Home page Orari Chi siamo Dove siamo
| Cerca: |
Ti trovi in: Strumenti musicali » Amplificazione » Monitor da Studio » Alesis M1Active monitor MK2 coppia di monitor bi amplificati
Alcuni marchi Modalità di pagamento Contrassegno Bonifico per l'Italia Bonifico per l'Estero Postepay Informazioni |
# Alesis M1Active monitor MK2 coppia di monitor bi amplificati
€ 430,00 prezzo online + € 90,00 di trasporto | € 450,00 prezzo in negozio
Disponibile
Descrizione: Alesis M1Active monitor MK2 coppia di monitor ATTIVI bi-amplificati 80W rms By combining our expertise in reference monitor design with our proven track record in studio amplification, Alesis' new M1 Active Biamplified Reference Monitor offers the incredibly accurate response that perfectly translates to every playback system. Its internal active crossover and custom-designed dual amplifiers ensure an extremely consistent performance under a variety of different studio conditions and program material. The result is a broad, extremely flat frequency response, clear imaging with a wide sweet spot, high power handling and detailed high- and mid-frequency response that only a professional powered monitor can deliver. Custom Drivers Designed For Active Monitoring * The M1 Active's woofer and tweeter were specifically designed for the most linear, low distortion response in powered monitoring applications. Its 6.5" woofer cone is formulated from non-woven carbon fiber. It's a material that has been used for the skins of combat aircraft wings, since it offers high tensile strength and low weight. In fact, carbon fiber is 25% lighter than polypropylene (the most common driver material) and hence provides quicker transient response in the low frequency range for superb bass response as well as a vast improvement in the detail of critical upper-mid frequencies. The M1 Active's 1" tweeter dome is made of pure silk, which offers a natural response that aids in preventing ear fatigue during long mix sessions. It also features an internal pole piece mounted phasing plug and is ferrofluid cooled to maintain the best balance of transient response to power handling. Active Bi-Amplifiers and Electronic Crossovers * Two audiophile-quality amplifiers-a 75 watt woofer amp and a 25 watt tweeter amp-were developed for the M1 Active, along with 4th order high- and low-pass electronic crossover filters. The crossover point was carefully chosen at a low 2 kHz, and produces an extremely wide dispersion zone as well as low midrange coloration. Also, the special time alignment circuitry that's been added to the tweeter section of this crossover allows the output of frequencies from the high and low drivers to occur in perfect synchronization, avoiding the time smear that's typical in less advanced powered speakers. Attractive Cabinet Design with Dual Ports and Offset Tweeter * In developing the M1 Active, the Alesis engineering team discovered that dual font-facing ports provided the fastest, most coherent and extended low frequency augmentation. Also, the unique offset design of the high frequency driver allows for the flattest frequency and power response in a speaker that offers such wide dispersion. The M1 Active's attractive mirror-imaged, charcoal- toned cabinet and magnetically-shielded drivers allow for placement in close proximity with computer or video monitors, and offers the added benefit of blending beautifully into your studio's decor without being obtrusive. They may be mounted in either a horizontal or vertical placement to best fit your studio's requirements. The Alesis M1 Active * With the lineage of our TEC Award-winning Monitor Onet Studio Reference Monitor, Alesis speakers have already become a standard in project and professional studios around the world. If you're looking for the same great accuracy and detailed response in a powered system that's truly affordable, the answer is clear: the new M1 Active from Alesis. Low Frequency Driver: 6.5" non-woven carbon fiber with Santoprene surround and dual magnet shielded configuration High Frequency Driver: 1" silk dome with medium viscosity ferrofluid coolant and dual magnet shielded configuration Crossover: 1500Hz, 8th-order, 48dB/octave filters Input Impedance: 20k_ balanced, 10k_ unbalanced LF Filter: 2nd order, "optimal Q" high pass, +1dB boost@50Hz LF Amplifier: 75 watts, 8_ load LF Amp Distortion:less than 0.03% thd @ 30w lf amp slew rate:<>19V/µsec LF Amp S/N Ratio: >110dB, ref. 60W @ 8_, A-wtg., 1kHz HF Amplifier: 25 watts, 4_ load HF Amp Distortion:less than 0.06% thd @ rated power lf amp slew rate less than 9V/µsec HF Amp S/N Ratio: >112dB @ rated output Frequency Range: 38 Hz - 23.5 kHz (-10dB point) Connectors: Combination XLR-1/4" jack with input level control Dimensions: (WxHxD) 8.5"x15"x9.75" (381mm x 216mm x 248mm) Weight: 19.5 lbs. (8.9kg) each. Enclosure Type * Ported Powered/Unpowered * c Frequency Response (Hz-kHz) * 45 Hz-22 kHz Crossover Frequency (kHz) * 2 kHz Woofer Size/Type * 6.5" non-woven carbon filter Tweeter Size/Type * 1" silk dome Magnetic Shielding * Yes Cabinet Dimensions (HxWxD in inches) * 8.5x15x9.25 Weight (lbs.) * 21
Dati a cura del produttore/fornitore. I prezzi sono da intendersi IVA inclusa e le spese di spedizione possono diminuire se si acquistano più prodotti contemporaneamente (con un risparmio sul costo di trasporto). Questo articolo potrebbe essere fuori produzione o non presente in catalogo e il prezzo potrebbe essere diverso da quello presente in questa pagina. Music House aggiorna e varia le informazioni alla richiesta del prodotto da parte del Cliente. Questo prodotto è acquistabile solo se il distributore possiede ancora l'articolo in catalogo con prezzo invariato; nel caso in cui ci fossero modifiche relative al prodotto stesso e/o al suo prezzo, Music House informerà il Cliente anticipatamente e questi, se ancora interessato, potrà prenotarlo individualmente. Questo avviso esiste soltanto a scopo informativo.
Legenda: = Richiedi informazioni sul prodotto tramite e-mail = Il prodotto è disponibile = Il prodotto non è disponibile = Trasporto gratuito n.d. = Spese di spedizioni non disponibili. Contattateci per un preventivo. = Acquista il prodotto
Condizioni di vendita | Post vendita | Diritto di recesso | Privacy | FAQ | Lavora con noi | Sei un rivenditore? | Link Log-in Music House Bari - P. IVA: 04718980727 Music House è in viale Einaudi 12/abc, 70125 BARI (Italy) Tel/Fax: 080/5019521 Tutti i nomi dei prodotti, i logotipi, i marchi ed i simboli sono di proprietà delle rispettive società. © Copyright 2005-2015 Aproweb. Tutti i diritti riservati. Pagina elaborata in 0,0273 secondi.